@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2009 Teus Benschop.
+ ** Copyright (©) 2003-2012 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -206,11 +206,11 @@ AssistantBase("Export", "export")
   gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_bible_opendocument), radiobutton_bible_type_group);
   radiobutton_bible_type_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_bible_opendocument));
 
-  //radiobutton_bible_gobible = gtk_radio_button_new_with_mnemonic (NULL, "Go Bible");
-  //gtk_widget_show (radiobutton_bible_gobible);
-  //gtk_box_pack_start (GTK_BOX (vbox_bible_type), radiobutton_bible_gobible, FALSE, FALSE, 0);
-  //gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_bible_gobible), radiobutton_bible_type_group);
-  //radiobutton_bible_type_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_bible_gobible));
+  radiobutton_bible_gobible = gtk_radio_button_new_with_mnemonic (NULL, "Go Bible");
+  gtk_widget_show (radiobutton_bible_gobible);
+  gtk_box_pack_start (GTK_BOX (vbox_bible_type), radiobutton_bible_gobible, FALSE, FALSE, 0);
+  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_bible_gobible), radiobutton_bible_type_group);
+  radiobutton_bible_type_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_bible_gobible));
 
   Shortcuts shortcuts_select_bible_type (0);
   shortcuts_select_bible_type.button (radiobutton_bible_usfm);
@@ -218,7 +218,7 @@ AssistantBase("Export", "export")
   shortcuts_select_bible_type.button (radiobutton_bible_osis);
   shortcuts_select_bible_type.button (radiobutton_bible_sword);
   shortcuts_select_bible_type.button (radiobutton_bible_opendocument);
-  //shortcuts_select_bible_type.button (radiobutton_bible_gobible);
+  shortcuts_select_bible_type.button (radiobutton_bible_gobible);
   shortcuts_select_bible_type.consider_assistant();
   shortcuts_select_bible_type.process();
 
@@ -777,7 +777,11 @@ void ExportAssistant::on_assistant_apply ()
         }
         case ebtGoBible:
         {
-          export_to_go_bible (bible_name, foldername);
+          if (gw_find_program_in_path("gobiblecreator")) {
+            export_to_go_bible (bible_name, foldername);
+          } else {
+            gtkw_dialog_info (NULL, "The GoBibleCreator was not found. Install it. See the online help.");
+          }
           break;
         }
       }
@@ -1083,9 +1087,9 @@ ExportBibleType ExportAssistant::get_bible_type ()
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radiobutton_bible_opendocument))) {
     return ebtOpenDocument;
   }
-  //if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radiobutton_bible_gobible))) {
-    //return ebtGoBible;
-  //}
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (radiobutton_bible_gobible))) {
+    return ebtGoBible;
+  }
   return ebtUSFM;
 }
 
