@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2009 Teus Benschop.
+ ** Copyright (©) 2003-2012 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -80,7 +80,7 @@ private:
   GtkWidget *radiobutton_bible_osis;
   GtkWidget *radiobutton_bible_sword;
   GtkWidget *radiobutton_bible_opendocument;
-  //GtkWidget *radiobutton_bible_gobible;
+  GtkWidget *radiobutton_bible_gobible;
   ExportBibleType get_bible_type ();
 
   // USFM export type.
