@@ -1,5 +1,5 @@
 /*
-** Copyright (©) 2003-2009 Teus Benschop.
+** Copyright (©) 2003-2012 Teus Benschop.
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -360,14 +360,10 @@ void ImportNotesDialog::unicode_page()
   ustring path = temporary_file(TEMP_FILE);
   // See whether the file contents is proper Unicode
   ustring file_contents;
-  bool unicode_valid = true;
-  {
-    gchar *s;
-    if (!g_file_get_contents(path.c_str(), &s, NULL, NULL))
-      unicode_valid = false;
-    file_contents = s;
-    g_free(s);
-  }
+  gchar *s;
+  g_file_get_contents(path.c_str(), &s, NULL, NULL);
+  file_contents = s;
+  g_free(s);
 }
 
 
