@@ -1,5 +1,5 @@
 /*
- ** Copyright (©) 2003-2009 Teus Benschop.
+ ** Copyright (©) 2003-2012 Teus Benschop.
  **  
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -152,24 +152,30 @@ gboolean FloatingWindow::on_title_bar_motion_notify_event (GtkWidget *widget, Gd
 gboolean FloatingWindow::on_title_bar_motion_notify (GdkEventMotion *event)
 {
   if (dragging_window) {
+    guint layout_width, layout_height;
+    gtk_layout_get_size (GTK_LAYOUT (layout), &layout_width, &layout_height);
     gint event_x = event->x_root;
     gint event_y = event->y_root;
     if (previous_root_x >= 0) {
       bool move_box = false;
       if (event_x != previous_root_x) {
         gint new_x = my_gdk_rectangle.x + event_x - previous_root_x;
-        // The user cannot move the window off the window at the left side.
+        // The window does not move beyond the left or right side 
         if (new_x >= 0) {
-          my_gdk_rectangle.x = new_x;
-          move_box = true;
+          if ((new_x + my_gdk_rectangle.width) <= layout_width) {
+            my_gdk_rectangle.x = new_x;
+            move_box = true;
+          }
         }
       }
       if (event_y != previous_root_y) {
         gint new_y = my_gdk_rectangle.y + event_y - previous_root_y;
-        // The user cannot move the window under the toolbar or menubar.
+        // The window does not move beyond the top or bottom.
         if (new_y >= 0) {
-          my_gdk_rectangle.y = new_y;
-          move_box = true;
+          if ((new_y + my_gdk_rectangle.height) <= layout_height) {
+            my_gdk_rectangle.y = new_y;
+            move_box = true;
+          }
         }
       }
       if (move_box) {
@@ -225,17 +231,31 @@ gboolean FloatingWindow::on_status_bar_motion_notify (GdkEventMotion *event)
     gw_destroy_source (resize_event_id);
     resize_event_id = g_timeout_add_full(G_PRIORITY_DEFAULT, 200, GSourceFunc(on_resize_timeout), gpointer(this), NULL);
     gtk_widget_hide (vbox_client);
+    guint layout_width, layout_height;
+    gtk_layout_get_size (GTK_LAYOUT (layout), &layout_width, &layout_height);
     gint event_x = event->x_root;
     gint event_y = event->y_root;
     if (previous_root_x >= 0) {
       bool resize_box = false;
       if (event_x != previous_root_x) {
-        my_gdk_rectangle.width = my_gdk_rectangle.width + event_x - previous_root_x;
-        resize_box = true;
+        gint new_width = my_gdk_rectangle.width + event_x - previous_root_x;
+        // Window should not become too narrow, or too wide for the screen.
+        if (new_width >= 100) {
+          if ((my_gdk_rectangle.x + new_width) <= layout_width) {
+            my_gdk_rectangle.width = new_width;
+            resize_box = true;
+          }
+        }
       }
       if (event_y != previous_root_y) {
-        my_gdk_rectangle.height = my_gdk_rectangle.height + event_y - previous_root_y;
-        resize_box = true;
+        gint new_height = my_gdk_rectangle.height + event_y - previous_root_y;
+        // Window should not become too short, or too tall for the screen.
+        if (new_height >= 100) {
+          if ((my_gdk_rectangle.y + new_height) <= layout_height) {
+            my_gdk_rectangle.height = new_height;
+            resize_box = true;
+          }
+        }
       }
       if (resize_box) {
         gtk_widget_set_size_request (vbox_window, my_gdk_rectangle.width, my_gdk_rectangle.height);
